@@ -148,15 +148,21 @@ class CachePath(AugmentedPath):
         raise NotImplementedError('implement in subclasses')
         # FIXME mkdir and put it in a more conventional location
 
+    @property
+    def _trashed_path(self):
+        return self.trash / f'{self.parent.id}-{self.id}-{self.name}'
+
+    @property
+    def _trashed_path_short(self):
+        return self.trash / self.name  # FIXME SIGH
+
     def crumple(self):  # FIXME change name to something more obvious ...
-        trashed = self.trash / f'{self.parent.id}-{self.id}-{self.name}'
         try:
-            self.rename(trashed)
+            self.rename(self._trashed_path)
         except OSError as e:
             if e.errno == 36:  # File name too long  # SIGH
-                trashed = self.trash / self.name  # FIXME SIGH
-                log.critical(f'Long name {self.name}')
-                self.rename(trashed)
+                log.critical(f'Had to rename trash {self._trashed_path} -> {self._trashed_path_short}')
+                self.rename(self._trashed_path_short)
             else:
                 raise e
 
@@ -210,9 +216,19 @@ class CachePath(AugmentedPath):
                 raise exc.AugPathlibError('aaaaaaaaaaaaaaaaaaaaaa') from e
 
             return child
+
+        elif isinstance(key, str):
+            child = self.local / key
+            if child.exists() or child.is_broken_symlink():
+                return child.cache
+            else:
+                raise FileNotFoundError('There is no local cached file with that name. Cannot construct cache.')
+
         else:
-            raise TypeError('Cannot construct a new CacheClass from an object '
-                            f'without an id and a name! {key}')
+            pass  # error incoming
+
+        raise TypeError('Cannot construct a new CacheClass from an object '
+                        f'without an id and a name! {key}')
 
     def __rtruediv__(self, cache):
         """ key is a subclass of self.__class__ """
