@@ -1,7 +1,9 @@
 import os
 import sys
+import errno
 import shutil
 import pathlib
+import tempfile
 import warnings
 import mimetypes
 import subprocess
@@ -19,15 +21,20 @@ except (ImportError, TypeError) as e:
 #from Xlib.display import Display
 #from Xlib import Xatom
 import augpathlib as aug
+from augpathlib import swap
 from augpathlib import exceptions as exc
 from augpathlib.meta import PathMeta
 from augpathlib.utils import log, default_cypher, StatResult, etag
 from augpathlib.utils import _bind_sysid_, AUG_XATTR_PREFIX
 
+SPARSE_KEY = (AUG_XATTR_PREFIX + '.sparse')
+
 _IGNORED_ERROS = (ENOENT, ENOTDIR, EBADF, ELOOP)
 _IGNORED_WINERRORS = (
     123,  # 'The filename, directory name, or volume label syntax is incorrect' -> 22 EINVAL
 )
+if sys.platform == 'darwin':
+    _IGNORED_ERROS += (errno.ENAMETOOLONG,)
 
 
 if os.name != 'nt':
@@ -47,6 +54,11 @@ else:
 
 if sys.version_info >= (3, 7):
     pathlib._IGNORED_ERROS += (ELOOP,)
+    if sys.platform == 'darwin':
+        # darwin gets very confused by self referential symlinks
+        # and it seems that they stack up on eachother while being
+        # dereferenced until the link name becomes too long
+        pathlib._IGNORED_ERROS += (errno.ENAMETOOLONG,)
 
 else:
 
@@ -113,6 +125,8 @@ class ADSHelper(EatHelper):
         This class allows ADS to pretend to work like xattrs.
     """
 
+    _sparse_key = SPARSE_KEY
+
     @staticmethod
     def _key_convention(key, namespace):
         return namespace + '.' + key  # FIXME maybe include xattrs. as well ??
@@ -237,6 +251,8 @@ class ADSHelper(EatHelper):
 class XattrHelper(EatHelper):
     """ pathlib helper augmented with xattr support """
 
+    _sparse_key = SPARSE_KEY.encode()
+
     def delxattr(self, key, fail=False, namespace=XATTR_DEFAULT_NS):
         try:
             xattr.remove(self.as_posix(), key, namespace=namespace)
@@ -262,7 +278,7 @@ class XattrHelper(EatHelper):
         try:
             return xattr.get(self.as_posix(), key, namespace=namespace)
         except OSError as e:
-            if e.errno == 61:
+            if e.errno == errno.ENODATA or e.errno == errno.ENOATTR:
                 raise exc.NoStreamError((self, key)) from e
             else:
                 raise e
@@ -448,8 +464,63 @@ class AugmentedPath(pathlib.Path):
     def rename(self, target):
         os.rename(self, target)
 
+    def swap_carefree(self, target):
+        """ swap two paths, use atomic if available on the system
+            and if the paths are on the same device otherwise fail
+
+            side note: there doesn't seem to be a standard name for
+            the superset of atomic and non-atomic, this operations
+            is definitely not non-atomic, it is maybe-atomic, but
+            maybe-atomic is too optimistic, thus carefree seems
+            appropriately ... disinterested in the exact semantics """
+        try:
+            self.swap(target)
+        except (Exception, NotImplementedError) as e:  # TODO clearer error handling
+            temp_str = tempfile.mkdtemp(dir=target.parent)
+            temp_dir = pathlib.Path(temp_str)
+            temp = temp_dir / target.name
+            # rename target -> temp
+            # rename self -> target
+            # rename target -> self
+            target.rename(temp)
+            self.rename(target)
+            temp.rename(self)
+            temp_dir.rmdir()
+
+    if sys.platform != 'linux': # just look at us not using pathlib's infra ...
+        _swap = swap.swap_not_implemented
+    else:
+        _swap = swap.swap_linux
+
+    def swap(self, target):
+        """ atomic swap of two paths
+
+            this will raise and error in the following cases
+            1. if the system has no atomic swap function such as renameat2
+            2. if the paths to be swapped are on different devices
+            3. if either path does not exist
+        """
+        se = self.exists()
+        te = target.exists()
+        if not se:
+            msg = f'Both self and target must exist self does not! {self}'
+            raise FileNotFoundError(msg)
+        elif not te:
+            msg = f'Both self and target must exist target does not! {target}'
+            raise FileNotFoundError(msg)
+
+        sd = self.stat().st_dev
+        td = target.stat().st_dev
+        if sd != td:
+            msg = f'Self and target must be on the same device! {sd} != {td}'
+            raise ValueError(msg) # FIXME find or make the correct error type
+
+        self._swap(target)
+
     def rmtree(self, ignore_errors=False, onerror=None, DANGERZONE=False):
         """ DANGER ZONE """
+        # FIXME make this atomic by renaming to a random name
+        # that doesn't exist and then calling rmtree on that
         if not self.is_absolute():
             raise exc.WillNotRemovePathError(f'Only absolute paths can be removed recursively. {self}')
 
@@ -530,12 +601,18 @@ class AugmentedPath(pathlib.Path):
 
     @property
     def mimetype(self):
+        if not self.is_absolute():  # needed for safe as_uri
+            self = self.resolve()
+
         mime, encoding = mimetypes.guess_type(self.as_uri())
         if mime:
             return mime
 
     @property
     def encoding(self):
+        if not self.is_absolute():  # needed for safe as_uri
+            self = self.resolve()
+
         mime, encoding = mimetypes.guess_type(self.as_uri())
         if encoding:
             return encoding
@@ -682,7 +759,7 @@ AugmentedPath._bind_flavours()
 
 class EatPath(EatHelper, AugmentedPath):
 
-    _sparse_key = (AUG_XATTR_PREFIX + '.sparse').encode()
+    # NOTE _sparse_key is set on each helper
 
     def _sparse_root(self):
         parent = self.parent
@@ -1105,7 +1182,12 @@ class LocalPath(EatPath, AugmentedPath):
     @property
     def children(self):
         if self.is_dir():
-            if self.cache is not None and self == self.cache.anchor.local:
+            if (self.cache is not None and
+                # relative paths inside may have a cache but no anchor
+                # the anchor itself can be relative and have an anchor
+                # so we test to see if there is an anchor first
+                self.cache.anchor and
+                self == self.cache.anchor.local):
                 cache_ignore = self._cache_class.cache_ignore
                 # implemented this way we can still use Path to navigate
                 # once we are inside local data dir, though all files there
@@ -1120,7 +1202,12 @@ class LocalPath(EatPath, AugmentedPath):
 
     @property
     def rchildren(self):
-        if self.is_dir() and self.cache is not None and self == self.cache.anchor.local:
+        if (self.is_dir() and self.cache is not None and
+            # relative paths inside may have a cache but no anchor
+            # the anchor itself can be relative and have an anchor
+            # so we test to see if there is an anchor first
+            self.cache.anchor and
+            self == self.cache.anchor.local):
             for path in self.children:
                 yield path
                 yield from path.rchildren
@@ -1204,9 +1291,12 @@ class XopenHelper:
 class XopenWindowsHelper(XopenHelper):
     _command = 'start'
 
-    def xopen(self):
-        """ open file using start """
-        process = subprocess.Popen([self._command, self],
+    def xopen(self, command=None):
+        """ open file using start or `command' if provided """
+        if command is None or not isinstance(command, str):
+            command = self._command
+
+        process = subprocess.Popen([command, self],
                                    stdout=subprocess.DEVNULL,
                                    stderr=subprocess.STDOUT)
 
@@ -1214,9 +1304,12 @@ class XopenWindowsHelper(XopenHelper):
 class XopenPosixHelper(XopenHelper):
     _command = 'open' if sys.platform == 'darwin' else 'xdg-open'
 
-    def xopen(self):
-        """ open file using xdg-open """
-        process = subprocess.Popen([self._command, self.as_posix()],
+    def xopen(self, command=None):
+        """ open file using xdg-open or `command' if provided """
+        if command is None or not isinstance(command, str):
+            command = self._command
+
+        process = subprocess.Popen([command, self.as_posix()],
                                    stdout=subprocess.DEVNULL,
                                    stderr=subprocess.STDOUT)
 
